pub struct Config {
pub overrides: Option<HashMap<String, Override>>,
pub metadata: Option<Metadata>,
}Expand description
The structure for a wkg.toml configuration file. This file is entirely optional and is used for overriding and annotating wasm packages.
Fields
overrides: Option<HashMap<String, Override>>Overrides for various packages
metadata: Option<Metadata>Additional metadata about the package. This will override any metadata already set by other tools.
Implementations
Sourceimpl Config
impl Config
Sourcepub async fn load_from_path(path: impl AsRef<Path>) -> Result<Config>
pub async fn load_from_path(path: impl AsRef<Path>) -> Result<Config>
Loads a configuration file from the given path.
Sourcepub async fn load() -> Result<Config>
pub async fn load() -> Result<Config>
Attempts to load the configuration from the current directory. Most of the time, users of this
crate should use this function. Right now it just checks for a wkg.toml file in the current
directory, but we could add more resolution logic in the future. If the file is not found, a
default empty config is returned.