pub struct LockedPackage {
pub name: PackageRef,
pub registry: Option<String>,
pub versions: Vec<LockedPackageVersion>,
}Expand description
Represents a locked package in a lock file.
Fields
name: PackageRefThe name of the locked package.
registry: Option<String>The registry the package was resolved from.
versions: Vec<LockedPackageVersion>The locked version of a package.
A package may have multiple locked versions if more than one
version requirement was specified for the package in wit.toml.