pub struct WorkspaceRootConfig {
pub members: Vec<PathBuf>,
pub metadata: Option<Metadata>,
/* private fields */
}Expand description
Intermediate configuration of a workspace root in a manifest.
Knows the Workspace Root path, as well as members and metadata, which
together tell if some path is recognized as a member by this root or not.
Fields
members: Vec<PathBuf>metadata: Option<Metadata>Implementations