Module resolver

Module resolver 

A resolver for resolving dependencies from a component registry.

Structs

DependencyResolutionMap
Represents a map of dependency resolutions.
DependencyResolver
Used to resolve dependencies for a WIT package.
LocalResolution
Represents information about a resolution of a local file.
PublishPlan
State for tracking dependencies during upload.
RegistryPackage
Represents a reference to a registry package.
RegistryResolution
Represents information about a resolution of a registry package.

Enums

DecodedDependency
Represents a decoded dependency.
Dependency
Represents a WIT package dependency.
DependencyResolution
Represents a resolution of a dependency.

Constants

DEFAULT_REGISTRY_NAME
The name of the default registry.

Type Aliases

DependencyGraph
Graph of publishable packages with the petgraph::Direction edges describing the dependency direction.
LocalPackageIndex
Mapping of PackageRefs to the respective index inside the dependency graph.