pub enum DependencyResolution {
Registry(RegistryResolution),
Local(LocalResolution),
}Expand description
Represents a resolution of a dependency.
Variants
Registry(RegistryResolution)
The dependency is resolved from a registry package.
Local(LocalResolution)
The dependency is resolved from a local path.
Implementations
Sourceimpl DependencyResolution
impl DependencyResolution
Sourcepub fn name(&self) -> &PackageRef
pub fn name(&self) -> &PackageRef
Gets the name of the dependency that was resolved.
Sourcepub fn version(&self) -> Option<&Version>
pub fn version(&self) -> Option<&Version>
Gets the resolved version.
Returns None if the dependency is not resolved from a registry package.
Sourcepub fn key(&self) -> Option<(&PackageRef, Option<&str>)>
pub fn key(&self) -> Option<(&PackageRef, Option<&str>)>
The key used in sorting and searching the lock file package list.
Returns None if the dependency is not resolved from a registry package.
Sourcepub async fn decode(&self) -> Result<DecodedDependency<'_>>
pub async fn decode(&self) -> Result<DecodedDependency<'_>>
Decodes the resolved dependency.