pub struct PublishPlan { /* private fields */ }Expand description
State for tracking dependencies during upload.
Implementations
Sourceimpl PublishPlan
impl PublishPlan
Sourcepub fn from_paths(paths: &[impl AsRef<Path>]) -> Result<Self>
pub fn from_paths(paths: &[impl AsRef<Path>]) -> Result<Self>
Generate Self from a list of WIT package paths (files or directories).
pub fn iter<'a>(&'a self) -> impl Iterator<Item = &'a PackageSpec> + 'a
pub fn is_empty(&self) -> bool
pub fn len(&self) -> usize
Sourcepub fn take_ready(&self) -> BTreeSet<PackageSpec>
pub fn take_ready(&self) -> BTreeSet<PackageSpec>
Returns the set of packages that are ready for publishing (i.e. have no outstanding dependencies).
These will not be returned in future calls.
Sourcepub fn get_path(&self, pkg: &PackageRef) -> Option<&Path>
pub fn get_path(&self, pkg: &PackageRef) -> Option<&Path>
Return the path associated with a local package.
Sourcepub fn get_node_index(&self, pkg: &PackageRef) -> Option<NodeIndex>
pub fn get_node_index(&self, pkg: &PackageRef) -> Option<NodeIndex>
Return the NodeIndex associated with a local package.
Sourcepub fn mark_confirmed(
&mut self,
published: impl IntoIterator<Item = PackageSpec>,
)
pub fn mark_confirmed( &mut self, published: impl IntoIterator<Item = PackageSpec>, )
Packages confirmed to be available in the registry, potentially allowing additional packages to be “ready”.