pub struct RegistryPackage {
pub name: Option<PackageRef>,
pub version: VersionReq,
pub registry: Option<String>,
}Expand description
Represents a reference to a registry package.
Fields
name: Option<PackageRef>The name of the package.
If not specified, the name from the mapping will be used.
version: VersionReqThe version requirement of the package.
registry: Option<String>The name of the component registry containing the package.
If not specified, the default registry is used.