pub struct RegistryResolution {
pub name: PackageRef,
pub package: PackageRef,
pub registry: Option<String>,
pub requirement: VersionReq,
pub version: Version,
pub digest: ContentDigest,
/* private fields */
}Expand description
Represents information about a resolution of a registry package.
Fields
name: PackageRefThe name of the dependency that was resolved.
This may differ from package if the dependency was renamed.
package: PackageRefThe name of the package from the registry that was resolved.
registry: Option<String>The name of the registry used to resolve the package if one was provided
requirement: VersionReqThe version requirement that was used to resolve the package.
version: VersionThe package version that was resolved.
digest: ContentDigestThe digest of the package contents.
Implementations