wasm_pkg_core

Module wit

source
Functions for building WIT packages and fetching their dependencies.

Enums

Functions

  • Builds a WIT package given the configuration and directory to parse. Will update the given lock file with the resolved dependencies but will not write it to disk.
  • Fetches and optionally updates all dependencies for the given path and writes them in the specified format. The lock file will be updated with the resolved dependencies but will not be written to disk.
  • Generate the list of all packages and their version requirement from the given path (a directory or file).
  • Populate a list of dependencies into the given directory. If the directory does not exist it will be created. Any existing files in the directory will be deleted. The dependencies will be put into the deps subdirectory within the directory in the format specified by the output type. Please note that if a local dep is encountered when using OutputType::Wasm and it isn’t a wasm binary, it will be copied directly to the directory and not packaged into a wit package first
  • Builds a list of resolved dependencies loaded from the component or path containing the WIT. This will configure the resolver, override any dependencies from configuration and resolve the dependency map. This map can then be used in various other functions for fetching the dependencies and/or building a final resolved package.