A resolver for resolving dependencies from a component registry.
Structs
- Dependency
Resolution Map - Represents a map of dependency resolutions.
- Dependency
Resolver - Used to resolve dependencies for a WIT package.
- Local
Resolution - Represents information about a resolution of a local file.
- Publish
Plan - State for tracking dependencies during upload.
- Registry
Package - Represents a reference to a registry package.
- Registry
Resolution - Represents information about a resolution of a registry package.
Enums
- Decoded
Dependency - Represents a decoded dependency.
- Dependency
- Represents a WIT package dependency.
- Dependency
Resolution - Represents a resolution of a dependency.
Constants
- DEFAULT_
REGISTRY_ NAME - The name of the default registry.
Type Aliases
- Dependency
Graph - Graph of publishable packages with the
petgraph::Directionedges describing the dependency direction. - Local
Package Index - Mapping of
PackageRefs to the respective index inside the dependency graph.